@@ -20,9 +20,7 @@
 #include "javaimport.h"
 #include "adaimport.h"
 #include "pascalimport.h"
-#ifndef DISABLE_CPP_IMPORT
 #include "cppimport.h"
-#endif
 #include "csharpimport.h"
 #include "codeimpthread.h"
 
@@ -52,13 +50,8 @@ ClassImport *ClassImport::createImporterByFileExt(const QString &fileName, CodeI
         classImporter = new PascalImport(thread);
     else if (fileName.endsWith(QLatin1String(".cs")))
         classImporter = new CSharpImport(thread);
-#ifndef DISABLE_CPP_IMPORT
     else
         classImporter = new CppImport(thread);  // the default.
-#else
-    else 
-        classImporter = 0;
-#endif
     return classImporter;
 }
 
