@@ -41,13 +41,11 @@
 
 #define PREPROCESSLEXER_DEBUG
 
-#ifdef Q_CC_MSVC
 template <class _Tp>
-struct _Identity : public std::unary_function<_Tp, _Tp> {
+struct identity : public std::unary_function<_Tp,_Tp> {
   _Tp& operator()(_Tp& __x) const { return __x; }
   const _Tp& operator()(const _Tp& __x) const { return __x; }
 };
-#endif
 
 template <class _Tp>
 struct tilde : public std::unary_function<_Tp, _Tp> {
@@ -193,7 +191,7 @@ struct numberLiteral :
 
         definition(numberLiteral const& self) {
             main =
-                (+ digit_p)
+                (ch_p('0') >> ch_p('x') >> + xdigit_p | + digit_p)
                 [ self.result_ = construct_<Token>(Token_number_literal, arg1, arg2)];
         }
     };
@@ -314,7 +312,7 @@ PreprocessLexer::~PreprocessLexer()
 }
 
 void PreprocessLexer::setSource(const QString& source,
-                                PositionFilename const& p_filename)
+                                const QString& p_filename)
 {
     reset();
     m_source.set_source(source, p_filename);
@@ -372,6 +370,20 @@ int PreprocessLexer::toInt(const Token& token)
     }
 }
 
+int PreprocessLexer::evaluateMacro(const QString &token)
+{
+    if (!m_driver->hasMacro(token)) {
+        uError() << "undefined macro" << token;
+        return 0;
+    }
+    Macro &m = m_driver->macro(token);
+    QString value = m.body().trimmed();
+    PreprocessLexer lexer(m_driver);
+    lexer.setSource(value, token);
+    int result = lexer.macroExpression();
+    return result;
+}
+
 void PreprocessLexer::nextLine()
 {
     m_source.parse((*gr_whiteSpace)
@@ -391,8 +403,13 @@ void PreprocessLexer::nextLine()
         while (!m_source.parse(eol_p).hit) {
             Token tk;
             nextToken(tk);
-            if (tk.type() != -1)
+            if (tk.type() != -1) {
                 m_preprocessedString += tk.text();
+                // TODO: Find a generic way to handle not expanded macros
+                // which are combined into invalid c code like Q_OBJECTpublic;
+                if (tk.type() == Token_Q_OBJECT)
+                    m_preprocessedString += QLatin1Char(';');
+            }
             if (m_source.currentChar().isNull())
                 break;
         }
@@ -593,7 +610,7 @@ void PreprocessLexer::dumpToFile()
     if (!d.exists())
         d.mkdir(tempPath);
 
-    QString fileName = tempPath + '/' + currentPosition().file.toString().replace(QRegExp("[/:mn]"), "-");
+    QString fileName = tempPath + '/' + currentPosition().file.replace(QRegExp("[/:mn]"), "-");
     QFile f(fileName);
     if (f.open(QIODevice::WriteOnly | QIODevice::Text)) {
         QTextStream out(&f);
@@ -839,7 +856,7 @@ int PreprocessLexer::macroPrimary()
         if (!l_hit)
             result = 0;
     } else {
-        boost::function < int (int) > l_op = _Identity<int>();
+        boost::function < int (int) > l_op = identity<int>();
         if (m_source.parse(ch_p('+')
                            | ch_p('-')[var(l_op) = std::negate<int>()]
                            | ch_p('!')[var(l_op) = std::logical_not<int>()]
@@ -854,8 +871,7 @@ int PreprocessLexer::macroPrimary()
             m_source.parse(
                 identifier_pg[assignFunctorResult<1>
                               (result,
-                               boost::bind(&Driver::hasMacro, m_driver,
-                                           _1))]
+                               boost::bind(&PreprocessLexer::evaluateMacro, boost::ref(*this), _1))]
                 | numberLiteral_pg[assignFunctorResult<1>
                                    (result,
                                     boost::bind(&PreprocessLexer::toInt, _1))]
