@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2013                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -13,23 +13,15 @@
 
 // app includes
 #include "uml.h"
-#include "umldoc.h"
-#include "stereotype.h"
 #include "umlwidget.h"
 
 // kde includes
-#if QT_VERSION < 0x050000
 #include <kinputdialog.h>
-#endif
-#include <KMessageBox>
-#include <KLocalizedString>
+#include <kmessagebox.h>
+#include <klocale.h>
 #include <klineedit.h>
-#include <kcombobox.h>
 
 // qt includes
-#if QT_VERSION >= 0x050000
-#include <QInputDialog>
-#endif
 #include <QGridLayout>
 #include <QLabel>
 #include <QLineEdit>
@@ -39,6 +31,7 @@ namespace Dialog_Utils {
 /**
  * Create a labeled text lineedit widget.
  *
+ * @param containingBox         The containing QGroupBox (unused).
  * @param layout                The QGridLayout to use.
  * @param row                   The row number within the QGridLayout.
  * @param label                 The QLabel object allocated (return value)
@@ -47,10 +40,9 @@ namespace Dialog_Utils {
  * @param editFieldText         Initialization text in the editField (optional.)
  * @return a pointer to the KLineEdit so you can setFocus() if necessary
  */
-KLineEdit* makeLabeledEditField(QGridLayout* layout,    int row,
-                                QLabel*     &label,     const QString& labelText,
-                                KLineEdit*  &editField, const QString& editFieldText /* = QString() */)
+KLineEdit* makeLabeledEditField(QGroupBox *containingBox, QGridLayout *layout, int row, QLabel * &label, const QString& labelText, KLineEdit * &editField, const QString& editFieldText /* = QString() */)
 {
+    Q_UNUSED(containingBox);
     label = new QLabel(labelText);
     layout->addWidget(label, row, 0);
     editField = new KLineEdit(editFieldText);
@@ -74,14 +66,7 @@ void askNameForWidget(UMLWidget * &targetWidget, const QString& dialogTitle,
 {
     bool pressedOK = false;
 
-#if QT_VERSION >= 0x050000
-    QString name = QInputDialog::getText(UMLApp::app(),
-                                         dialogTitle, dialogPrompt,
-                                         QLineEdit::Normal,
-                                         defaultName, &pressedOK);
-#else
     QString name = KInputDialog::getText(dialogTitle, dialogPrompt, defaultName, &pressedOK, UMLApp::app());
-#endif
 
     if (pressedOK) {
         targetWidget->setName(name);
@@ -92,36 +77,5 @@ void askNameForWidget(UMLWidget * &targetWidget, const QString& dialogTitle,
     }
 }
 
-/**
- * Helper function for inserting available stereotypes into a KComboBox
- *
- * @param kcb    The KComboBox into which to insert the stereotypes
- * @param type   The stereotype to activate
- */
-void insertStereotypesSorted(KComboBox *kcb, const QString& type)
-{
-    UMLDoc *umldoc = UMLApp::app()->document();
-    QStringList types;
-    types << QString();  // an empty stereotype is the default
-    foreach (UMLStereotype* ust, umldoc->stereotypes()) {
-        types << ust->name();
-    }
-    // add the given parameter
-    if (!types.contains(type)) {
-        types << type;
-    }
-    types.sort();
-
-    kcb->clear();
-    kcb->insertItems(-1, types);
-
-    // select the given parameter
-    int currentIndex = kcb->findText(type);
-    if (currentIndex > -1) {
-        kcb->setCurrentIndex(currentIndex);
-    }
-    kcb->completionObject()->addItem(type);
-}
-
 }  // end namespace Dialog_Utils
 
