@@ -95,10 +95,6 @@ public:
 
     bool isUnique(UMLListViewItem * item, const QString &name);
 
-    void startRename(UMLListViewItem * item);
-    void cancelRename(UMLListViewItem * item);
-    void endRename(UMLListViewItem * item);
-
     void setSelected(UMLListViewItem * item, bool state) { setItemSelected((QTreeWidgetItem*)item, state);  }
     void setStartedCut(bool startedCut);
     void setStartedCopy(bool startedCopy);
@@ -128,13 +124,12 @@ public:
 
 protected:
     bool event(QEvent *e);
-    bool eventFilter(QObject *o, QEvent *e);
     void mouseReleaseEvent(QMouseEvent *me);
     void mousePressEvent(QMouseEvent *me);
     void mouseMoveEvent(QMouseEvent *me);
     void mouseDoubleClickEvent(QMouseEvent *me);
     void focusOutEvent (QFocusEvent *fe);
-
+    void contextMenuEvent(QContextMenuEvent *me);
     UMLDragData* getDragData();
 
     bool acceptDrag(QDropEvent* event) const;
@@ -142,6 +137,7 @@ protected:
     void dragEnterEvent(QDragEnterEvent* event);
     void dragMoveEvent(QDragMoveEvent* event);
     void dropEvent(QDropEvent* event);
+    void commitData(QWidget *editor);
 
     UMLListViewItem * findUMLObjectInFolder(UMLListViewItem *folder, UMLObject *obj);
 
@@ -169,7 +165,7 @@ public slots:
 
     void slotObjectChanged();
 
-    void popupMenuSel(QAction* action);
+    void slotMenuSelection(QAction* action);
 
     void slotDropped(QDropEvent* de, UMLListViewItem* parent, UMLListViewItem* item);
 
@@ -177,9 +173,9 @@ public slots:
     void collapseAll(UMLListViewItem *item);
 
     void slotCutSuccessful();
+    void slotDeleteSelectedItems();
 
 protected slots:
-    void slotItemChanged(QTreeWidgetItem *, int);
     void slotItemSelectionChanged();
     void slotExpanded(QTreeWidgetItem* item);
     void slotCollapsed(QTreeWidgetItem* item);
@@ -193,14 +189,11 @@ private:
     UMLListViewItem* m_rv;         ///< root view (home)
     UMLListViewItem* m_lv[Uml::ModelType::N_MODELTYPES];  ///< predefined list view roots
     UMLListViewItem* m_datatypeFolder;
-    ListPopupMenu*   m_menu;
     UMLDoc*          m_doc;
     bool             m_bStartedCut;
     bool             m_bStartedCopy;
     bool m_bCreatingChildObject;  ///< when creating an attribute or an operation to stop it adding a second listViewItem
-    bool m_bRenameInProgress;
     QPoint m_dragStartPosition;
-    UMLListViewItem* m_editItem;
 };
 
 #endif
