@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2013                                               *
- *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
+ *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
 // own header
@@ -13,11 +13,11 @@
 
 // local includes
 #include "association.h"
+#include "associationwidget.h"
 #include "assocpropdlg.h"
 #include "classifier.h"
 #include "cmds.h"
 #include "debug_utils.h"
-#include "floatingtextwidgetcontroller.h"
 #include "linkwidget.h"
 #include "listpopupmenu.h"
 #include "messagewidget.h"
@@ -30,6 +30,7 @@
 #include "umlview.h"
 
 // kde includes
+#include <kfontdialog.h>
 #include <kinputdialog.h>
 #include <klocale.h>
 
@@ -50,14 +51,18 @@ DEBUG_REGISTER_DISABLED(FloatingTextWidget)
  * @param id The ID to assign (-1 will prompt a new ID.)
  */
 FloatingTextWidget::FloatingTextWidget(UMLScene * scene, Uml::TextRole::Enum role, const QString& text, Uml::ID::Type id)
-  : UMLWidget(scene, WidgetBase::wt_Text, id, new FloatingTextWidgetController(this)),
+  : UMLWidget(scene, WidgetBase::wt_Text, id),
     m_linkWidget(0),
     m_preText(QString()),
     m_postText(QString()),
-    m_textRole(role)
+    m_textRole(role),
+    m_unconstrainedPositionX(0),
+    m_unconstrainedPositionY(0),
+    m_movementDirectionX(0),
+    m_movementDirectionY(0)
 {
     m_Text = text;
-    UMLWidget::m_resizable = false;
+    m_resizable = false;
     setZValue(10); //make sure always on top.
 }
 
@@ -102,8 +107,8 @@ void FloatingTextWidget::setText(const QString &t)
         m_linkWidget->seqNumAndOp(seqNum, op);
         if (seqNum.length() > 0 || op.length() > 0) {
             if (! m_scene->showOpSig())
-                op.replace( QRegExp("\\(.*\\)"), "()" );
-            m_Text = seqNum.append(": ").append( op );
+                op.replace(QRegExp("\\(.*\\)"), "()");
+            m_Text = seqNum.append(": ").append(op);
         }
         else
             m_Text = t;
@@ -112,7 +117,7 @@ void FloatingTextWidget::setText(const QString &t)
         m_Text = t;
     }
 
-    UMLSceneSize s = minimumSize();
+    QSizeF s = minimumSize();
     setSize(s.width(), s.height());
 
     updateGeometry();
@@ -158,12 +163,12 @@ QString FloatingTextWidget::displayText() const
 /**
  * Overrides method from UMLWidget.
  */
-UMLSceneSize FloatingTextWidget::minimumSize()
+QSizeF FloatingTextWidget::minimumSize()
 {
     const QFontMetrics &fm = getFontMetrics(FT_NORMAL);
     int h = fm.lineSpacing();
-    int w = fm.width( displayText() );
-    return UMLSceneSize(w + 8, h + 4);  // give a small margin
+    int w = fm.width(displayText());
+    return QSizeF(w + 8, h + 4);  // give a small margin
 }
 
 /**
@@ -173,7 +178,7 @@ UMLSceneSize FloatingTextWidget::minimumSize()
  */
 void FloatingTextWidget::setTextcmd(const QString &t)
 {
-    UMLApp::app()->executeCommand(new Uml::CmdSetTxt(this,t));
+    UMLApp::app()->executeCommand(new Uml::CmdSetTxt(this, t));
 }
 
 /**
@@ -211,6 +216,10 @@ void FloatingTextWidget::showOperationDialog()
     }
 
     QPointer<SelectOpDlg> selectDlg = new SelectOpDlg(m_scene->activeView(), c);
+    if (m_scene->autoIncrementSequence()) {
+        seqNum = m_scene->autoIncrementSequenceValue(1);
+        selectDlg->setAutoIncrementSequence(true);
+    }
     selectDlg->setSeqNumber(seqNum);
     if (m_linkWidget->operation() == 0) {
         selectDlg->setCustomOp(opText);
@@ -227,7 +236,7 @@ void FloatingTextWidget::showOperationDialog()
                 UMLClassifierList selfAndAncestors = c->findSuperClassConcepts();
                 selfAndAncestors.prepend(c);
                 UMLOperation *op = 0;
-                foreach (UMLClassifier *cl , selfAndAncestors) {
+                foreach (UMLClassifier *cl, selfAndAncestors) {
                     op = cl->findOperation(od.m_name, od.m_args);
                     if (op) {
                         break;
@@ -251,6 +260,10 @@ void FloatingTextWidget::showOperationDialog()
             m_linkWidget->setOperation(0);
         }
         m_linkWidget->setSeqNumAndOp(seqNum, opText);
+        m_scene->setAutoIncrementSequence(selectDlg->autoIncrementSequence());
+        if (selectDlg->autoIncrementSequence())
+            m_scene->setAutoIncrementSequenceValue(seqNum);
+
         setMessageText();
     }
     delete selectDlg;
@@ -303,7 +316,7 @@ QString FloatingTextWidget::postText() const
  * @param ChangeLog Pointer to the IDChangeLog.
  * @return  true for success
  */
-bool FloatingTextWidget::activate( IDChangeLog* ChangeLog /*= 0 */)
+bool FloatingTextWidget::activate(IDChangeLog* ChangeLog /*= 0 */)
 {
     if (! UMLWidget::activate(ChangeLog))
         return false;
@@ -364,7 +377,7 @@ void FloatingTextWidget::handleRename()
         t = i18n("Enter multiplicity:");
         /*
         // NO! shouldn't be allowed
-        } else if (m_textRole == Uml::TextRole::ChangeA || m_textRole == Uml::TextRole::ChangeB ) {
+        } else if (m_textRole == Uml::TextRole::ChangeA || m_textRole == Uml::TextRole::ChangeB) {
         t = i18n("Enter changeability");
         */
     } else if (m_textRole == Uml::TextRole::Name) {
@@ -459,6 +472,116 @@ bool FloatingTextWidget::isTextValid(const QString &text)
     return false;
 }
 
+/**
+ * Returns a constrained position for the widget after applying the position
+ * difference.
+ * If no link widget exists, the position returned is the current widget
+ * position with the difference applied. If there's a link, the position
+ * to be returned is constrained using constrainTextPos method from the
+ * LinkWidget, if any.
+ *
+ * @param diffX The difference between current X position and new X position.
+ * @param diffY The difference between current Y position and new Y position.
+ * @return A QPointF with the constrained new position.
+ */
+QPointF FloatingTextWidget::constrainPosition(qreal diffX, qreal diffY)
+{
+    qreal newX = x() + diffX;
+    qreal newY = y() + diffY;
+
+    if (link()) {
+        link()->constrainTextPos(newX, newY, width(), height(), textRole());
+    }
+
+    return QPointF(newX, newY);
+}
+
+/**
+ * Overridden from UMLWidget.
+ * Moves the widget to a new position using the difference between the
+ * current position and the new position.
+ * If the floating text widget is part of a sequence message, and the
+ * message widget is selected, it does nothing: the message widget will
+ * update the text position when it's moved.
+ * In any other case, the floating text widget constrains its move using
+ * constrainPosition. When the position of the floating text is constrained,
+ * it's kept at that position until it can be moved to another valid
+ * position (m_unconstrainedPositionX/Y and m_movementDirectionX/Y are
+ * used for that).
+ * Moreover, if is part of a sequence message (and the message widget
+ * isn't selected), it updates the position of the message widget.
+ * @see constrainPosition
+ *
+ * @param diffX The difference between current X position and new X position.
+ * @param diffY The difference between current Y position and new Y position.
+ */
+void FloatingTextWidget::moveWidgetBy(qreal diffX, qreal diffY)
+{
+    if (textRole() == Uml::TextRole::Seq_Message_Self)
+        return;
+
+    if (textRole() == Uml::TextRole::Seq_Message
+                    && ((MessageWidget*)link())->isSelected()) {
+        return;
+    }
+
+    m_unconstrainedPositionX += diffX;
+    m_unconstrainedPositionY += diffY;
+    QPointF constrainedPosition = constrainPosition(diffX, diffY);
+
+    qreal newX = constrainedPosition.x();
+    qreal newY = constrainedPosition.y();
+
+    if (!m_movementDirectionX) {
+        if (m_unconstrainedPositionX != constrainedPosition.x()) {
+            m_movementDirectionX = (diffX > 0)? 1: -1;
+        }
+    } else if ((m_movementDirectionX < 0 && m_unconstrainedPositionX > x()) ||
+               (m_movementDirectionX > 0 && m_unconstrainedPositionX < x()) ) {
+        newX = m_unconstrainedPositionX;
+        m_movementDirectionX = 0;
+    }
+
+    if (!m_movementDirectionY) {
+        if (m_unconstrainedPositionY != constrainedPosition.y()) {
+            m_movementDirectionY = (diffY > 0)? 1: -1;
+        }
+    } else if ((m_movementDirectionY < 0 && m_unconstrainedPositionY > y()) ||
+               (m_movementDirectionY > 0 && m_unconstrainedPositionY < y()) ) {
+        newY = m_unconstrainedPositionY;
+        m_movementDirectionY = 0;
+    }
+
+    setX(newX);
+    setY(newY);
+
+    if (link()) {
+        link()->calculateNameTextSegment();
+        if (textRole() == Uml::TextRole::Seq_Message) {
+            MessageWidget* messageWidget = (MessageWidget*)link();
+            messageWidget->setY(newY + height());
+        }
+    }
+}
+
+/**
+ * Overridden from UMLWidget.
+ * Modifies the value of the diffX and diffY variables used to move the
+ * widgets.
+ * The values are constrained using constrainPosition.
+ * @see constrainPosition
+ *
+ * @param diffX The difference between current X position and new X position.
+ * @param diffY The difference between current Y position and new Y position.
+ */
+void FloatingTextWidget::constrainMovementForAllWidgets(qreal &diffX, qreal &diffY)
+{
+    QPointF constrainedPosition = constrainPosition(diffX, diffY);
+
+    diffX = constrainedPosition.x() - x();
+    diffY = constrainedPosition.y() - y();
+}
+
 /**
  * Overrides default method
  */
@@ -469,7 +592,7 @@ void FloatingTextWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem
 
     int w = width();
     int h = height();
-    painter->setFont( UMLWidget::font() );
+    painter->setFont(UMLWidget::font());
     painter->setPen(textColor());
     painter->drawText(0, 0, w, h, Qt::AlignCenter, displayText());
 
@@ -513,8 +636,8 @@ void FloatingTextWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
     textElement.setAttribute("posttext", m_postText);
 
     /* No need to save these - the messagewidget already did it.
-    m_Operation  = qElement.attribute( "operation", "" );
-    m_SeqNum = qElement.attribute( "seqnum", "" );
+    m_Operation  = qElement.attribute("operation", "");
+    m_SeqNum = qElement.attribute("seqnum", "");
      */
 
     textElement.setAttribute("role", m_textRole);
@@ -574,7 +697,7 @@ void FloatingTextWidget::slotMenuSelection(QAction* action)
     case ListPopupMenu::mt_Change_Font:
         {
             QFont fnt = font();
-            if(KFontDialog::getFont(fnt, KFontChooser::NoDisplayFlags, m_scene->activeView()) ) {
+            if(KFontDialog::getFont(fnt, KFontChooser::NoDisplayFlags, m_scene->activeView())) {
                 if(m_textRole == Uml::TextRole::Floating || m_textRole == Uml::TextRole::Seq_Message) {
                     setFont(fnt);
                 } else if (m_linkWidget) {
@@ -603,7 +726,7 @@ void FloatingTextWidget::setMessageText()
 {
     if (m_linkWidget) {
         m_linkWidget->setMessageText(this);
-        UMLSceneSize s = minimumSize();
+        QSizeF s = minimumSize();
         setSize(s.width(), s.height());
 
     }
